#!/usr/bin/env python3
"""Structure I/O for SAbR.

This package provides structure file handling including:
- Reading PDB/mmCIF files
- Threading alignments onto structures
- Writing renumbered structures
"""
