#!/usr/bin/env python3
"""Neural network modules for SAbR.

This package contains the neural network components adapted from SoftAlign:
- END_TO_END: Combined embedding and alignment model
- ENC: MPNN encoder for structure embeddings
- Smith-Waterman: Differentiable alignment algorithms

These modules use JAX and Haiku for neural network operations.
"""
