#!/usr/bin/env python3
"""Alignment engine for SAbR.

This package provides the alignment functionality for SAbR including:
- SoftAligner: Main alignment class
- SoftAlignOutput: Output dataclass
- AlignmentBackend: JAX/Haiku backend for alignment
- HMM conversion utilities
- Deterministic correction functions
"""
