#!/usr/bin/env python3
"""Embedding generation for SAbR.

This package provides the embedding functionality for SAbR including:
- MPNNEmbeddings: Dataclass for per-residue embeddings
- EmbeddingBackend: JAX/Haiku backend for embedding computation
- Input extraction from PDB/CIF files and BioPython chains
"""
